==> openj9-18_0.33.1.orig.tar.xz: src-openj9-18-0.33.1/openj9/test/functional/Java8andUp/src/org/openj9/test/annotation/defaults/AnnotationTestClassDefaults.java <==
package org.openj9.test.annotation.defaults;

/*******************************************************************************
 * Copyright (c) 2010, 2018 IBM Corp. and others
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution and
 * is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] http://openjdk.java.net/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0 WITH Classpath-exception-2.0 OR LicenseRef-GPL-2.0 WITH Assembly-exception
 *******************************************************************************/

import org.openj9.test.annotation.ClassAnnotation;
import org.openj9.test.annotation.ConstructorAnnotation;
import org.openj9.test.annotation.FieldAnnotation;
import org.openj9.test.annotation.MethodAnnotation;
import org.openj9.test.annotation.ParameterAnnotation;
import org.openj9.test.annotation.ValueAnnotation;

@ValueAnnotation()
@ClassAnnotation
public class AnnotationTestClassDefaults {
	@ValueAnnotation() @FieldAnnotation() public String field;

	@ValueAnnotation()
	@ConstructorAnnotation()
	public AnnotationTestClassDefaults(@ParameterAnnotation() @Deprecated() String param1,
			@ParameterAnnotation String param2) {
	}

	@ValueAnnotation()
	@MethodAnnotation()
	public void method(@ParameterAnnotation() @Deprecated() String param1, @ParameterAnnotation String param2) {
	}
}

==> openj9-21_0.56.0.orig.tar.xz: src-openj9-21-0.56.0/openj9/test/functional/Java8andUp/src/org/openj9/test/annotation/defaults/AnnotationTestClassDefaults.java <==
package org.openj9.test.annotation.defaults;

/*
 * Copyright IBM Corp. and others 2010
 *
 * This program and the accompanying materials are made available under
 * the terms of the Eclipse Public License 2.0 which accompanies this
 * distribution and is available at https://www.eclipse.org/legal/epl-2.0/
 * or the Apache License, Version 2.0 which accompanies this distribution and
 * is available at https://www.apache.org/licenses/LICENSE-2.0.
 *
 * This Source Code may also be made available under the following
 * Secondary Licenses when the conditions for such availability set
 * forth in the Eclipse Public License, v. 2.0 are satisfied: GNU
 * General Public License, version 2 with the GNU Classpath
 * Exception [1] and GNU General Public License, version 2 with the
 * OpenJDK Assembly Exception [2].
 *
 * [1] https://www.gnu.org/software/classpath/license.html
 * [2] https://openjdk.org/legal/assembly-exception.html
 *
 * SPDX-License-Identifier: EPL-2.0 OR Apache-2.0 OR GPL-2.0-only WITH Classpath-exception-2.0 OR GPL-2.0-only WITH OpenJDK-assembly-exception-1.0
 */

import org.openj9.test.annotation.ClassAnnotation;
import org.openj9.test.annotation.ConstructorAnnotation;
import org.openj9.test.annotation.FieldAnnotation;
import org.openj9.test.annotation.MethodAnnotation;
import org.openj9.test.annotation.ParameterAnnotation;
import org.openj9.test.annotation.ValueAnnotation;

@ValueAnnotation()
@ClassAnnotation
public class AnnotationTestClassDefaults {
	@ValueAnnotation() @FieldAnnotation() public String field;

	@ValueAnnotation()
	@ConstructorAnnotation()
	public AnnotationTestClassDefaults(@ParameterAnnotation() @Deprecated() String param1,
			@ParameterAnnotation String param2) {
	}

	@ValueAnnotation()
	@MethodAnnotation()
	public void method(@ParameterAnnotation() @Deprecated() String param1, @ParameterAnnotation String param2) {
	}
}
